@@ -26,38 +26,36 @@
 #define DATA_FILE TESTS_DATA_DIR "/test-selection.xml"
 
 static void
-teardown_selection_test (gpointer fixture, gconstpointer user_data)
+atk_test_selection_sample_get_interface (TestAppFixture *fixture, gconstpointer user_data)
 {
-  terminate_app ();
-}
-
-static void
-atk_test_selection_sample_get_interface (gpointer fixture, gconstpointer user_data)
-{
-  AtspiAccessible *obj = get_root_obj (DATA_FILE);
-  g_assert_cmpstr (atspi_accessible_get_name (obj, NULL), ==, "root_object");
+  AtspiAccessible *obj = fixture->root_obj;
+  check_name (obj, "root_object");
   AtspiAccessible *child = atspi_accessible_get_child_at_index (obj, 0, NULL);
   AtspiSelection *iface = atspi_accessible_get_selection_iface (child);
   g_assert (iface != NULL);
+  g_object_unref (iface);
+  g_object_unref (child);
 }
 
 static void
-atk_test_selection_get_n_selected_children (gpointer fixture, gconstpointer user_data)
+atk_test_selection_get_n_selected_children (TestAppFixture *fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj (DATA_FILE);
-  g_assert_cmpstr (atspi_accessible_get_name (obj, NULL), ==, "root_object");
+  AtspiAccessible *obj = fixture->root_obj;
+  check_name (obj, "root_object");
   AtspiAccessible *child = atspi_accessible_get_child_at_index (obj, 0, NULL);
   AtspiSelection *iface = atspi_accessible_get_selection_iface (child);
   g_assert (iface != NULL);
 
   g_assert_cmpint (atspi_selection_get_n_selected_children (iface, NULL), ==, 3);
+  g_object_unref (iface);
+  g_object_unref (child);
 }
 
 static void
-atk_test_selection_get_selected_child (gpointer fixture, gconstpointer user_data)
+atk_test_selection_get_selected_child (TestAppFixture *fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj (DATA_FILE);
-  g_assert_cmpstr (atspi_accessible_get_name (obj, NULL), ==, "root_object");
+  AtspiAccessible *obj = fixture->root_obj;
+  check_name (obj, "root_object");
   AtspiAccessible *child = atspi_accessible_get_child_at_index (obj, 0, NULL);
   AtspiSelection *iface = atspi_accessible_get_selection_iface (child);
   g_assert (iface != NULL);
@@ -70,15 +68,18 @@ atk_test_selection_get_selected_child (gpointer fixture, gconstpointer user_data
   for (i = 0; i < selected_count; i++)
     {
       o = atspi_selection_get_selected_child (iface, i, NULL);
-      g_assert_cmpstr (atspi_accessible_get_name (o, NULL), ==, valid_names[i]);
+      check_name (o, valid_names[i]);
+      g_object_unref (o);
     }
+  g_object_unref (iface);
+  g_object_unref (child);
 }
 
 static void
-atk_test_selection_select_child (gpointer fixture, gconstpointer user_data)
+atk_test_selection_select_child (TestAppFixture *fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj (DATA_FILE);
-  g_assert_cmpstr (atspi_accessible_get_name (obj, NULL), ==, "root_object");
+  AtspiAccessible *obj = fixture->root_obj;
+  check_name (obj, "root_object");
   AtspiAccessible *child = atspi_accessible_get_child_at_index (obj, 0, NULL);
   AtspiSelection *iface = atspi_accessible_get_selection_iface (child);
   g_assert (iface != NULL);
@@ -88,13 +89,15 @@ atk_test_selection_select_child (gpointer fixture, gconstpointer user_data)
   atspi_selection_select_child (iface, 2, NULL);
   atspi_selection_select_child (iface, 3, NULL);
   g_assert_cmpint (atspi_selection_get_n_selected_children (iface, NULL), ==, 5);
+  g_object_unref (iface);
+  g_object_unref (child);
 }
 
 static void
-atk_test_selection_deselect_selected (gpointer fixture, gconstpointer user_data)
+atk_test_selection_deselect_selected (TestAppFixture *fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj (DATA_FILE);
-  g_assert_cmpstr (atspi_accessible_get_name (obj, NULL), ==, "root_object");
+  AtspiAccessible *obj = fixture->root_obj;
+  check_name (obj, "root_object");
   AtspiAccessible *child = atspi_accessible_get_child_at_index (obj, 0, NULL);
   AtspiSelection *iface = atspi_accessible_get_selection_iface (child);
   g_assert (iface != NULL);
@@ -107,13 +110,15 @@ atk_test_selection_deselect_selected (gpointer fixture, gconstpointer user_data)
 
   atspi_selection_deselect_selected_child (iface, 2, NULL);
   g_assert_cmpint (atspi_selection_get_n_selected_children (iface, NULL), ==, 4);
+  g_object_unref (iface);
+  g_object_unref (child);
 }
 
 static void
-atk_test_selection_deselect_child (gpointer fixture, gconstpointer user_data)
+atk_test_selection_deselect_child (TestAppFixture *fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj (DATA_FILE);
-  g_assert_cmpstr (atspi_accessible_get_name (obj, NULL), ==, "root_object");
+  AtspiAccessible *obj = fixture->root_obj;
+  check_name (obj, "root_object");
   AtspiAccessible *child = atspi_accessible_get_child_at_index (obj, 0, NULL);
   AtspiSelection *iface = atspi_accessible_get_selection_iface (child);
   g_assert (iface != NULL);
@@ -126,13 +131,15 @@ atk_test_selection_deselect_child (gpointer fixture, gconstpointer user_data)
 
   atspi_selection_deselect_child (iface, 2, NULL);
   g_assert_cmpint (atspi_selection_get_n_selected_children (iface, NULL), ==, 4);
+  g_object_unref (iface);
+  g_object_unref (child);
 }
 
 static void
-atk_test_selection_is_child_selected (gpointer fixture, gconstpointer user_data)
+atk_test_selection_is_child_selected (TestAppFixture *fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj (DATA_FILE);
-  g_assert_cmpstr (atspi_accessible_get_name (obj, NULL), ==, "root_object");
+  AtspiAccessible *obj = fixture->root_obj;
+  check_name (obj, "root_object");
   AtspiAccessible *child = atspi_accessible_get_child_at_index (obj, 0, NULL);
   AtspiSelection *iface = atspi_accessible_get_selection_iface (child);
   g_assert (iface != NULL);
@@ -142,13 +149,15 @@ atk_test_selection_is_child_selected (gpointer fixture, gconstpointer user_data)
   g_assert (atspi_selection_is_child_selected (iface, 4, NULL));
   g_assert (!atspi_selection_is_child_selected (iface, 2, NULL));
   g_assert (!atspi_selection_is_child_selected (iface, 3, NULL));
+  g_object_unref (iface);
+  g_object_unref (child);
 }
 
 static void
-atk_test_selection_select_all (gpointer fixture, gconstpointer user_data)
+atk_test_selection_select_all (TestAppFixture *fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj (DATA_FILE);
-  g_assert_cmpstr (atspi_accessible_get_name (obj, NULL), ==, "root_object");
+  AtspiAccessible *obj = fixture->root_obj;
+  check_name (obj, "root_object");
   AtspiAccessible *child = atspi_accessible_get_child_at_index (obj, 0, NULL);
   AtspiSelection *iface = atspi_accessible_get_selection_iface (child);
   g_assert (iface != NULL);
@@ -156,13 +165,15 @@ atk_test_selection_select_all (gpointer fixture, gconstpointer user_data)
   g_assert_cmpint (atspi_selection_get_n_selected_children (iface, NULL), ==, 3);
   atspi_selection_select_all (iface, NULL);
   g_assert_cmpint (atspi_selection_get_n_selected_children (iface, NULL), ==, 5);
+  g_object_unref (iface);
+  g_object_unref (child);
 }
 
 static void
-atk_test_selection_clear_selection (gpointer fixture, gconstpointer user_data)
+atk_test_selection_clear_selection (TestAppFixture *fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj (DATA_FILE);
-  g_assert_cmpstr (atspi_accessible_get_name (obj, NULL), ==, "root_object");
+  AtspiAccessible *obj = fixture->root_obj;
+  check_name (obj, "root_object");
   AtspiAccessible *child = atspi_accessible_get_child_at_index (obj, 0, NULL);
   AtspiSelection *iface = atspi_accessible_get_selection_iface (child);
   g_assert (iface != NULL);
@@ -170,27 +181,29 @@ atk_test_selection_clear_selection (gpointer fixture, gconstpointer user_data)
   g_assert_cmpint (atspi_selection_get_n_selected_children (iface, NULL), ==, 3);
   atspi_selection_clear_selection (iface, NULL);
   g_assert_cmpint (atspi_selection_get_n_selected_children (iface, NULL), ==, 0);
+  g_object_unref (iface);
+  g_object_unref (child);
 }
 
 void
 atk_test_selection (void)
 {
-  g_test_add_vtable (ATK_TEST_PATH_SELECTION "/atk_test_selection_sample_get_interface",
-                     0, NULL, NULL, atk_test_selection_sample_get_interface, teardown_selection_test);
-  g_test_add_vtable (ATK_TEST_PATH_SELECTION "/atk_test_selection_get_n_selected_children",
-                     0, NULL, NULL, atk_test_selection_get_n_selected_children, teardown_selection_test);
-  g_test_add_vtable (ATK_TEST_PATH_SELECTION "/atk_test_selection_get_selected_child",
-                     0, NULL, NULL, atk_test_selection_get_selected_child, teardown_selection_test);
-  g_test_add_vtable (ATK_TEST_PATH_SELECTION "/atk_test_selection_select_child",
-                     0, NULL, NULL, atk_test_selection_select_child, teardown_selection_test);
-  g_test_add_vtable (ATK_TEST_PATH_SELECTION "/atk_test_selection_deselect_selected",
-                     0, NULL, NULL, atk_test_selection_deselect_selected, teardown_selection_test);
-  g_test_add_vtable (ATK_TEST_PATH_SELECTION "/atk_test_selection_deselect_child",
-                     0, NULL, NULL, atk_test_selection_deselect_child, teardown_selection_test);
-  g_test_add_vtable (ATK_TEST_PATH_SELECTION "/atk_test_selection_is_child_selected",
-                     0, NULL, NULL, atk_test_selection_is_child_selected, teardown_selection_test);
-  g_test_add_vtable (ATK_TEST_PATH_SELECTION "/atk_test_selection_select_all",
-                     0, NULL, NULL, atk_test_selection_select_all, teardown_selection_test);
-  g_test_add_vtable (ATK_TEST_PATH_SELECTION "/atk_test_selection_clear_selection",
-                     0, NULL, NULL, atk_test_selection_clear_selection, teardown_selection_test);
+  g_test_add ("/selection/atk_test_selection_sample_get_interface",
+              TestAppFixture, DATA_FILE, fixture_setup, atk_test_selection_sample_get_interface, fixture_teardown);
+  g_test_add ("/selection/atk_test_selection_get_n_selected_children",
+              TestAppFixture, DATA_FILE, fixture_setup, atk_test_selection_get_n_selected_children, fixture_teardown);
+  g_test_add ("/selection/atk_test_selection_get_selected_child",
+              TestAppFixture, DATA_FILE, fixture_setup, atk_test_selection_get_selected_child, fixture_teardown);
+  g_test_add ("/selection/atk_test_selection_select_child",
+              TestAppFixture, DATA_FILE, fixture_setup, atk_test_selection_select_child, fixture_teardown);
+  g_test_add ("/selection/atk_test_selection_deselect_selected",
+              TestAppFixture, DATA_FILE, fixture_setup, atk_test_selection_deselect_selected, fixture_teardown);
+  g_test_add ("/selection/atk_test_selection_deselect_child",
+              TestAppFixture, DATA_FILE, fixture_setup, atk_test_selection_deselect_child, fixture_teardown);
+  g_test_add ("/selection/atk_test_selection_is_child_selected",
+              TestAppFixture, DATA_FILE, fixture_setup, atk_test_selection_is_child_selected, fixture_teardown);
+  g_test_add ("/selection/atk_test_selection_select_all",
+              TestAppFixture, DATA_FILE, fixture_setup, atk_test_selection_select_all, fixture_teardown);
+  g_test_add ("/selection/atk_test_selection_clear_selection",
+              TestAppFixture, DATA_FILE, fixture_setup, atk_test_selection_clear_selection, fixture_teardown);
 }
